# frozen_string_literal: true
require 'commander'
require 'mnoe_cli'
require 'mnoe_cli/commands'

module MnoeCli
  class Cli
    include Commander::Methods

    def run
      program :name, 'mnoe_cli'
      program :version, MnoeCli::VERSION
      program :description, 'Mnoe CLI toolbelt'
      default_command :help

      command :generate_version_log do |c|
        c.syntax = 'mnoe_cli generate_version_log [OPTIONS]'
        c.summary = 'Generate a frontend changelog'
        c.example 'Generate a version log', 'generate_version_log'
        c.example 'Generate a version log with specific branches', 'generate_version_log --current origin/master --next origin/develop'
        c.option '--current STRING', String, 'Current version (default: @{u}'
        c.option '--next STRING', String, 'Next version (default: HEAD)'
        c.option '--format STRING', String, 'Output format (only supporting Github at the moment)'
       c.action do |args, options|
          options.default current: '@{u}',
                          next: 'HEAD'
          MnoeCli::Commands::GenerateVersionLog.run(args, options)
        end
      end

      run!
    end
  end
end
